Citing Harmonica
================

This is research software **made by scientists**. Citations help us justify the
effort that goes into building and maintaining this project.

If you used this software in your research, please consider
citing the following source: https://doi.org/10.5281/zenodo.3628741

The link above includes full citation information and export formats (BibTeX,
Mendeley, etc).
